@@ -341,7 +341,7 @@ class PrepareTrainingSetArrays(PrepareArrays):
                                                                            self.bcut, self.ignore_classes)), 'rb') as f:
                 orig_lc = pickle.load(f)
 
-        classes = list(set(labels))
+        classes = sorted(list(set(labels)))
 
         # Count nobjects per class
         for c in classes:
@@ -399,7 +399,7 @@ class PrepareTrainingSetArrays(PrepareArrays):
             for i in range(lenX):
                 if i % 1000 == 0:
                     print(f"new {i} of {lenX}")
-                mask = timesX_local[i] > 0
+                mask = timesX_local[i] >= 0
                 nmask = sum(mask)
                 newX[i][:nmask] = X_local[i][mask]
                 newy[i][:nmask] = y_local[i][mask]
