@@ -60,6 +60,10 @@ class InputLightCurve(object):
             self.class_number = training_set_parameters['class_number']
             self.peakmjd = training_set_parameters['peakmjd']
 
+        if self.known_redshift and (np.isnan(redshift) or redshift is None):
+            raise(f"Redshift of object {objid} is unknown but you are trying to classify with the known_redshift model."
+                  f"Please input the redshift or set known_redshift to False when classifying this object.")
+
         self.b = self.get_galactic_latitude()
         self.trigger_mjd, self.t = self.get_trigger_time()
 
@@ -90,7 +94,7 @@ class InputLightCurve(object):
         """ Calculate the explosion time for the trianing set if certain conditions are met. """
         calc_params = True
         inrange_mask = self.t < self.peakmjd
-        if int(self.class_number) in [70, 80, 82, 83]:  # No t0 if model types (AGN, RRlyrae, Eclipsing Binaries)
+        if self.class_number in [70, 80, 82, 83]:  # No t0 if model types (AGN, RRlyrae, Eclipsing Binaries)
             calc_params = False
         elif self.peakmjd - self.trigger_mjd < 0:  # No t0 if trigger to peak time is small
             calc_params = False
